@@ -5,11 +5,12 @@ from configparser import ConfigParser
 from pathlib import Path
 
 BASE_DIR = Path(__file__).resolve().parent
-
+CONFIG_FILE = os.path.join(BASE_DIR,'config.ini')
 DBNAME = "base.sqlite3"
 
 config = ConfigParser()
-config.read(os.path.join(BASE_DIR.parent,'config.ini'))
+config.read(CONFIG_FILE)
+
 
 
 
@@ -40,9 +41,9 @@ def draw():
     
     try:
         cursor.execute(QUERY)
-        print("handling tables done ")
+        print("handling tables done \n")
     except Exception as e:
-        print(f"error executing QUERY [Error : {e} ] ")
+        print(f"error executing QUERY [Error : {e} ] \n ")
 
     db.commit()
     
