@@ -1,17 +1,24 @@
-DEV = False
+DEV = True
 import typer
 import os
 
 
 if not DEV:
     from .db import delete, draw,fetch,drop,update_data,insert_data
-    from ..config import reader,write
+    from .config import reader,write
 else:
     from db import delete, draw,fetch,drop,update_data,insert_data
     from config import write,reader
 
 
 
+def handle_path(path:str):
+    path = path.replace("/","\\")
+    if path.endswith("\\"):
+        return path+"mikasa.sqlite3"
+    else:
+        return path+"\\mikasa.sqlite3"
+    
 
 
 
@@ -23,16 +30,14 @@ app = typer.Typer()
 
 
 @app.command()
-def config(group,key,value):
-    write(group,key,value)
+def config(value):
+    write(handle_path(value))
 
-if not reader.get("config","db"):
-    print("please set the path of the database [you can add your old database that you've been using with Mikasa tool ] : ")
+
+if not reader.has_section("config") or not reader.has_option("config","db"):
+    print("please insert your database path \n")
     typer.run(config)
-    # draw the database 
-    draw()
 else:
-    # draw the database 
     draw()
 
 
